##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/status/operation/StatusInspect)Check Portainer status  Deprecated
Deprecated: use the `/system/status` endpoint instead. Retrieve Portainer status **Access policy** : public
### Responses
**200**
Success
get/status
https://api-docs.portainer.io/api/status
###  Response samples
  * 200


Content type
application/json
Copy
`{

  *  "InstanceID": "299ab403-70a8-4c05-92f7-bf7a994d50df",

  *  "Version": "2.0.0"

 }`
